Use Case:  View personally authored content
===========================================

Actor
-----

Content Creator

Assumptions
-----------

* Content Creator has logged into the CMF (see :doc:`LoginAsMember`).

* Content Creator has created content (:doc:`CreateNewContent`).

Procedure
---------

1. Click the 'search' link in the top navigation bar.  The
   system displays the advanced search page.

2. Enter your user ID in the form field labled *Creator*. Make sure you spell
   it exactly as you type it in to login to the CMF.

3. Click the search button at the bottom of the page. The system then
   displayes a list of all content you've personally created using the standard
   search results page [#]_.

.. :rubric::Notes

.. [#]
   For a more detailed description of the options for advanced searching,
   see "Search CMF Site":SearchCMFSite.
